==> moodle-1.5-mysql.tgz: moodle/lang/nl/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 ALPHA (2005042300)


$string['calendar'] = 'Kalender';
$string['calendarheading'] = '$a Kalender';
$string['clickhide'] = 'Verberg';
$string['clickshow'] = 'Toon';
$string['confirmeventdelete'] = 'Wil je deze activiteit echt wissen?';
$string['courseevents'] = 'Vak';
$string['dayview'] = 'Per dag';
$string['daywithnoevents'] = 'Vandaag geen activiteiten';
$string['default'] = 'Standaard';
$string['deleteevent'] = 'Wis activiteit';
$string['detailedmonthview'] = 'Gedetaileerd maandoverzicht';
$string['durationminutes'] = 'Duur in minuten';
$string['durationnone'] = 'Geen tijdsduur';
$string['durationuntil'] = 'Tot';
$string['editevent'] = 'Bewerk activiteit';
$string['errorbeforecoursestart'] = 'Je kunt geen activiteit plannen voor de startdatum van het vak';
$string['errorinvaliddate'] = 'Ongeldige datum';
$string['errorinvalidminutes'] = 'Geef de duur in minuten met een getal tussen 1 en 999';
$string['errorinvalidrepeats'] = 'Geef het aantal activiteiten met een getal tussen 1 en 99';
$string['errornodescription'] = 'Beschrijving verplicht';
$string['errornoeventname'] = 'Naam verplicht';
$string['eventdate'] = 'Datum';
$string['eventdescription'] = 'Beschrijving';
$string['eventduration'] = 'Tijdsduur';
$string['eventendtime'] = 'Eindigt';
$string['eventinstanttime'] = 'Uur';
$string['eventkind'] = 'Soort activiteit';
$string['eventname'] = 'Naam';
$string['eventrepeat'] = 'Herhalingen';
$string['eventsfor'] = '$a activiteiten';
$string['eventstarttime'] = 'Startuur';
$string['eventtime'] = 'Uur';
$string['eventview'] = 'Details';
$string['expired'] = 'Verloopt';
$string['explain_lookahead'] = 'Met deze instelling stel je het (maximum) aantal dagen in de toekomst in dat een activiteit moet starten om weergegeven te worden als een komende activiteit. Activiteiten die later dan dat aantal dagen zullen gebeuren, worden niet getoond als komende activiteit. Merk op dat <strong> er geen garantie is </strong> dat alle activiteiten in dit tijdskader getoond zullen worden; als er teveel zijn (meer dan de instelling \"maximumaantal getoonde activiteiten \") dan zullen de activiteiten die het verst in de toekomst liggen niet getoond worden.';
$string['explain_maxevents'] = 'Deze instelling stelt het maximumaantal komende activiteiten in dat getoond kan worden. Als je hier een groot getal ingeeft, dan is het mogelijk dat het tonen van de komende activiteiten een groot deel van je scherm zal innemen.';
$string['explain_persistflt'] = 'Als deze optie ingeschakeld is, dan zal Moodle je laatste gebeurtenisfilter opslaan en die telkens wanneer je je aanmeldt automatisch gebruiken.';
$string['explain_startwday'] = 'Een kalenderweek zal starten op de dag die je hier kiest.';
$string['explain_timeformat'] = 'Je kunt kiezen of de tijd in 12- of 24-uurformaat wordt weergegeven. Als je voor de standaardinstelling kiest, dan zal het formaat automatisch gekozen worden volgens de taal die je gebruikt op je site.';
$string['fri'] = 'Vr';
$string['friday'] = 'Vrijdag';
$string['globalevents'] = 'Site';
$string['gotocalendar'] = 'Bekijk de kalender';
$string['groupevents'] = 'Groep';
$string['hidden'] = 'verborgen';
$string['manyevents'] = '$a activiteiten';
$string['mon'] = 'Ma';
$string['monday'] = 'Maandag';
$string['monthlyview'] = 'Per maand';
$string['newevent'] = 'Nieuwe activiteit';
$string['noupcomingevents'] = 'Er zijn geen activiteiten op komst';
$string['oneevent'] = '1 activiteit';
$string['pref_lookahead'] = 'Aantal dagen vooruit kijken naar komende activiteiten';
$string['pref_maxevents'] = 'maximumaantal getoonde activiteiten';
$string['pref_persistflt'] = 'Filsterinstellingen opslaan';
$string['pref_startwday'] = 'Eerste dag van de week';
$string['pref_timeformat'] = 'Tijdsweergave';
$string['preferences'] = 'Voorkeuren';
$string['preferences_available'] = 'Persoonlijke voorkeuren';
$string['repeateditall'] = 'Pas de wijzigingen toe op alle $a gebeurtenissen in deze reeks herhalingen';
$string['repeateditthis'] = 'Pas de wijzigingen alleen op deze gebeurtenis toe';
$string['repeatnone'] = 'Geen herhalingen';
$string['repeatweeksl'] = 'Herhaal deze activiteit';
$string['repeatweeksr'] = 'weken';
$string['sat'] = 'Za';
$string['saturday'] = 'Zaterdag';
$string['shown'] = 'Getoond';
$string['spanningevents'] = 'Komende activiteiten';
$string['sun'] = 'Zo';
$string['sunday'] = 'Zondag';
$string['thu'] = 'Do';
$string['thursday'] = 'Donderdag';
$string['timeformat_12'] = '12-uur (am/pm)';
$string['timeformat_24'] = '24-uur';
$string['today'] = 'Vandaag';
$string['tomorrow'] = 'Morgen';
$string['tt_deleteevent'] = 'Wis activiteit';
$string['tt_editevent'] = 'Bewerk activiteit';
$string['tt_hidecourse'] = 'Vakactiviteiten worden getoond (klik om te verbergen)';
$string['tt_hideglobal'] = 'Site-activiteiten worden getoond (klik om te verbergen)';
$string['tt_hidegroups'] = 'Groepsactiviteiten worden getoond (klik om te verbergen)';
$string['tt_hideuser'] = 'Persoonlijke activiteiten worden getoond (klik om te verbergen)';
$string['tt_showcourse'] = 'Vakactiviteiten zijn  verborgen (klik om te tonen)';
$string['tt_showglobal'] = 'Site-activiteiten zijn verborgen (klik om te tonen)';
$string['tt_showgroups'] = 'Groepactiviteiten zijn verborgen (klik om te tonen';
$string['tt_showuser'] = 'Gebruikersactiviteiten zijn  verborgen (klik om te tonen';
$string['tue'] = 'Di';
$string['tuesday'] = 'Dinsdag';
$string['typecourse'] = 'Vak';
$string['typegroup'] = 'Groep';
$string['typesite'] = 'Site';
$string['typeuser'] = 'Persoonlijk';
$string['upcomingevents'] = 'Komende activiteit';
$string['userevents'] = 'Persoonlijk';
$string['wed'] = 'Wo';
$string['wednesday'] = 'Woensdag';
$string['yesterday'] = 'Gisteren';
$string['youcandeleteallrepeats'] = 'Deze gebeurtenis is er n uit een herhalingsreeks. Je kunt alleen deze gebeurtenis of alle $a gebeurtenissen van deze reeks tegelijk verwijderen.';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/nl/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 ALPHA (2005042300)


$string['calendar'] = 'Kalender';
$string['calendarheading'] = '$a Kalender';
$string['clickhide'] = 'Verberg';
$string['clickshow'] = 'Toon';
$string['confirmeventdelete'] = 'Wil je deze activiteit echt wissen?';
$string['courseevents'] = 'Cursus';
$string['dayview'] = 'Per dag';
$string['daywithnoevents'] = 'Vandaag geen activiteiten';
$string['default'] = 'Standaard';
$string['deleteevent'] = 'Wis activiteit';
$string['detailedmonthview'] = 'Gedetaileerd maandoverzicht';
$string['durationminutes'] = 'Duur in minuten';
$string['durationnone'] = 'Geen tijdsduur';
$string['durationuntil'] = 'Tot';
$string['editevent'] = 'Bewerk activiteit';
$string['errorbeforecoursestart'] = 'Je kunt geen activiteit plannen voor de startdatum van de cursus';
$string['errorinvaliddate'] = 'Ongeldige datum';
$string['errorinvalidminutes'] = 'Geef de duur in minuten met een getal tussen 1 en 999';
$string['errorinvalidrepeats'] = 'Geef het aantal activiteiten met een getal tussen 1 en 99';
$string['errornodescription'] = 'Beschrijving verplicht';
$string['errornoeventname'] = 'Naam verplicht';
$string['eventdate'] = 'Datum';
$string['eventdescription'] = 'Beschrijving';
$string['eventduration'] = 'Tijdsduur';
$string['eventendtime'] = 'Eindigt';
$string['eventinstanttime'] = 'Uur';
$string['eventkind'] = 'Soort activiteit';
$string['eventname'] = 'Naam';
$string['eventrepeat'] = 'Herhalingen';
$string['eventsfor'] = '$a activiteiten';
$string['eventstarttime'] = 'Startuur';
$string['eventtime'] = 'Uur';
$string['eventview'] = 'Details';
$string['expired'] = 'Verloopt';
$string['explain_lookahead'] = 'Met deze instelling stel je het (maximum) aantal dagen in de toekomst in dat een activiteit moet starten om weergegeven te worden als een komende activiteit. Activiteiten die later dan dat aantal dagen zullen gebeuren, worden niet getoond als komende activiteit. Merk op dat <strong> er geen garantie is </strong> dat alle activiteiten in dit tijdskader getoond zullen worden; als er teveel zijn (meer dan de instelling \"maximumaantal getoonde activiteiten \") dan zullen de activiteiten die het verst in de toekomst liggen niet getoond worden.';
$string['explain_maxevents'] = 'Deze instelling stelt het maximumaantal komende activiteiten in dat getoond kan worden. Als je hier een groot getal ingeeft, dan is het mogelijk dat het tonen van de komende activiteiten een groot deel van je scherm zal innemen.';
$string['explain_persistflt'] = 'Als deze optie ingeschakeld is, dan zal Moodle je laatste gebeurtenisfilter opslaan en die telkens wanneer je je aanmeldt automatisch gebruiken.';
$string['explain_startwday'] = 'Een kalenderweek zal starten op de dag die je hier kiest.';
$string['explain_timeformat'] = 'Je kunt kiezen of de tijd in 12- of 24-uurformaat wordt weergegeven. Als je voor de standaardinstelling kiest, dan zal het formaat automatisch gekozen worden volgens de taal die je gebruikt op je site.';
$string['fri'] = 'Vr';
$string['friday'] = 'Vrijdag';
$string['globalevents'] = 'Site';
$string['gotocalendar'] = 'Bekijk de kalender';
$string['groupevents'] = 'Groep';
$string['hidden'] = 'verborgen';
$string['manyevents'] = '$a activiteiten';
$string['mon'] = 'Ma';
$string['monday'] = 'Maandag';
$string['monthlyview'] = 'Per maand';
$string['newevent'] = 'Nieuwe activiteit';
$string['noupcomingevents'] = 'Er zijn geen activiteiten op komst';
$string['oneevent'] = '1 activiteit';
$string['pref_lookahead'] = 'Aantal dagen vooruit kijken naar komende activiteiten';
$string['pref_maxevents'] = 'maximumaantal getoonde activiteiten';
$string['pref_persistflt'] = 'Filterinstellingen opslaan';
$string['pref_startwday'] = 'Eerste dag van de week';
$string['pref_timeformat'] = 'Tijdsweergave';
$string['preferences'] = 'Voorkeuren';
$string['preferences_available'] = 'Persoonlijke voorkeuren';
$string['repeateditall'] = 'Pas de wijzigingen toe op alle $a gebeurtenissen in deze reeks herhalingen';
$string['repeateditthis'] = 'Pas de wijzigingen alleen op deze gebeurtenis toe';
$string['repeatnone'] = 'Geen herhalingen';
$string['repeatweeksl'] = 'Herhaal deze activiteit';
$string['repeatweeksr'] = 'weken';
$string['sat'] = 'Za';
$string['saturday'] = 'Zaterdag';
$string['shown'] = 'Getoond';
$string['spanningevents'] = 'Komende activiteiten';
$string['sun'] = 'Zo';
$string['sunday'] = 'Zondag';
$string['thu'] = 'Do';
$string['thursday'] = 'Donderdag';
$string['timeformat_12'] = '12-uur (am/pm)';
$string['timeformat_24'] = '24-uur';
$string['today'] = 'Vandaag';
$string['tomorrow'] = 'Morgen';
$string['tt_deleteevent'] = 'Wis activiteit';
$string['tt_editevent'] = 'Bewerk activiteit';
$string['tt_hidecourse'] = 'Cursusactiviteiten worden getoond (klik om te verbergen)';
$string['tt_hideglobal'] = 'Site-activiteiten worden getoond (klik om te verbergen)';
$string['tt_hidegroups'] = 'Groepsactiviteiten worden getoond (klik om te verbergen)';
$string['tt_hideuser'] = 'Persoonlijke activiteiten worden getoond (klik om te verbergen)';
$string['tt_showcourse'] = 'Cursusactiviteiten zijn  verborgen (klik om te tonen)';
$string['tt_showglobal'] = 'Site-activiteiten zijn verborgen (klik om te tonen)';
$string['tt_showgroups'] = 'Groepactiviteiten zijn verborgen (klik om te tonen';
$string['tt_showuser'] = 'Gebruikersactiviteiten zijn  verborgen (klik om te tonen';
$string['tue'] = 'Di';
$string['tuesday'] = 'Dinsdag';
$string['typecourse'] = 'Cursus';
$string['typegroup'] = 'Groep';
$string['typesite'] = 'Site';
$string['typeuser'] = 'Persoonlijk';
$string['upcomingevents'] = 'Komende activiteit';
$string['userevents'] = 'Persoonlijk';
$string['wed'] = 'Wo';
$string['wednesday'] = 'Woensdag';
$string['yesterday'] = 'Gisteren';
$string['youcandeleteallrepeats'] = 'Deze gebeurtenis is er n uit een herhalingsreeks. Je kunt alleen deze gebeurtenis of alle $a gebeurtenissen van deze reeks tegelijk verwijderen.';

?>
